@@ -33,10 +33,17 @@ __status__ = "Prototype"
 import laygo2.object
 import numpy as np
 
+from laygo2.object.physical import PhysicalObject
+from laygo2.object.grid import Grid
+from laygo2.object.template import Template
 
-class BaseDatabase:
+from laygo2._typing import T
+from typing import overload, Generic, Dict, Type, Union
+
+class BaseDatabase(Generic[T]):
     """
-    BaseDatabase is a base class implementing basic functions of various database objects such as library and design.
+    A base class that implements basic functions for 
+    various database objects, such as libraries and designs.
 
     Notes
     -----
@@ -44,7 +51,7 @@ class BaseDatabase:
     """
 
     name = None
-    """str: BaseDatabase object name.
+    """str: Name of BaseDatabase object.
 
     Example
     -------
@@ -59,7 +66,7 @@ class BaseDatabase:
     """
 
     params = None
-    """dict or None: Dictionary containing parameters of BaseDatabase object.
+    """dict or None: BaseDatabase object's parameter dictionary.
 
     Example
     -------
@@ -74,8 +81,8 @@ class BaseDatabase:
     **(Korean)** BaseDatabase의 속성.
     """
 
-    elements = None
-    """dict: Dictionary containing its element objects.
+    elements: Dict[str, Type[Union[PhysicalObject, T]]] = None
+    """dict: Element object dictionary.
 
     Example
     -------
@@ -109,8 +116,7 @@ class BaseDatabase:
 
     noname_index = 0
     """
-    int: A unique number used as the name of an unnamed object belonging to 
-    the database.    
+    int: Unique identifier index for unnamed objects.
 
     Example
     -------
@@ -135,7 +141,7 @@ class BaseDatabase:
     이름을 정할 때 부여되는 고유 번호.
     """
 
-    @property
+    # @property
     def keys(self):
         """Keys of elements.
 
@@ -162,11 +168,11 @@ class BaseDatabase:
         -----
         **(Korean)** BaseDatabase 객체의 구성 요소를 담고 있는 Dictionary.
         """
-        return self.elements.keys
+        return self.elements.keys()
 
     def items(self):
         """
-        key/object pair of elements.
+        Key-object pairs of elements.
 
         Parameters
         ----------
@@ -204,13 +210,19 @@ class BaseDatabase:
         """
         return self.elements.items()
 
+    @overload
+    def __getitem__(self: "BaseDatabase[T]", pos) -> Type[T]: ...
+    @overload
+    def __getitem__(self: "BaseDatabase[None]", pos) -> Type[PhysicalObject]: ...
+
     def __getitem__(self, pos):
         """
-        Return the object corresponding to the key.
+        Return the object corresponding to pos.
 
         Parameters
         ----------
-        key : str
+        pos : str
+            Name of object.
 
         Returns
         -------
@@ -257,10 +269,7 @@ class BaseDatabase:
         Parameters
         ----------
         key : str
-
-        Returns
-        -------
-        list
+            Object key (name).
 
         Example
         -------
@@ -289,17 +298,17 @@ class BaseDatabase:
         self.append(item)
 
     def append(self, item):
-        """(Simply) add a physical object to the BaseDatabase object.
+        """Add physical object to BaseDatabase without taking any further actions.
 
         Parameters
         ----------
         item : laygo2.object.physical.PhysicalObject
-            The physical object to be added.
+            Physical object to be added.
 
         Returns
         -------
         list :
-            A list containing the name of item and the item itself ([item.name, item]).
+            List of item name and item ([item.name, item]).
 
         Example
         -------
@@ -358,8 +367,8 @@ class BaseDatabase:
             return item_name, item
 
     def __iter__(self):
-        """Iterator function. Directly mapped to its elements.
-
+        """Element-mapped direct iterator function.
+        
         Example
         -------
         >>> import laygo2
@@ -392,7 +401,7 @@ class BaseDatabase:
         return self.summarize()
 
     def summarize(self):
-        """Return the summary of the object information."""
+        """Get object information summary."""
         return (
             self.__repr__() + " " + "name: " + self.name + ", " + "params: " + str(self.params) + " \n"
             "    elements: " + str(self.elements) + ""
@@ -443,35 +452,7 @@ class BaseDatabase:
                 self.elements[e] = elements[e]
 
 
-class Library(BaseDatabase):
-    """
-    Library class implements the library management function.
-
-    Example
-    -------
-    >>> import laygo2
-    >>> lib = laygo2.object.database.Library(name="mylib")
-    >>> dsn0 = laygo2.object.database.Design(name="mycell0")
-    >>> dsn1 = laygo2.object.database.Design(name="mycell1")
-    >>> lib.append(dsn0)
-    >>> lib.append(dsn1)
-    >>> print(lib)
-    <laygo2.object.database.Library object at 0x0000025F2D25B8B0>
-    name: mylib, params: None
-    elements: {
-        'mycell0': <laygo2.object.database.Design object at 0x0000025F2D25B010>,
-        'mycell1': <laygo2.object.database.Design object at 0x0000025F2D25BF70>}
-
-    See Also
-    --------
-    laygo2.object.databse.Design: Check for more comprehensive Example.
-
-    Notes
-    -----
-    **(Korean)** Library 클래스는 라이브러리 관리 기능을 구현한다.
-
-    """
-
+class LibraryWrapper(BaseDatabase[T]):
     def get_libname(self):
         """getter function of libname property."""
         return self.name
@@ -495,7 +476,9 @@ class Library(BaseDatabase):
     **(Korean)** Library 객체의 이름.
     """
 
-    def append(self, item):
+    def append(self, item: T):
+        """Add physical object to Library without taking any further actions.
+        """
         if isinstance(item, list) or isinstance(item, np.ndarray):
             item_name_list = []
             item_list = []
@@ -545,19 +528,49 @@ class Library(BaseDatabase):
         BaseDatabase.__init__(self, name=name, params=params, elements=elements)
 
     def summarize(self):
-        """Return the summary of the object information."""
+        """Get object information summary."""
         return BaseDatabase.summarize(self)
 
+class Library(LibraryWrapper["Design"]):
+    """
+    Class for library management function implementation.
 
-class TemplateLibrary(Library):
-    """This class implements template libraries that contain templates as their child objects."""
+    Example
+    -------
+    >>> import laygo2
+    >>> lib = laygo2.object.database.Library(name="mylib")
+    >>> dsn0 = laygo2.object.database.Design(name="mycell0")
+    >>> dsn1 = laygo2.object.database.Design(name="mycell1")
+    >>> lib.append(dsn0)
+    >>> lib.append(dsn1)
+    >>> print(lib)
+    <laygo2.object.database.Library object at 0x0000025F2D25B8B0>
+    name: mylib, params: None
+    elements: {
+        'mycell0': <laygo2.object.database.Design object at 0x0000025F2D25B010>,
+        'mycell1': <laygo2.object.database.Design object at 0x0000025F2D25BF70>}
+
+    See Also
+    --------
+    laygo2.object.databse.Design: Check for more comprehensive Example.
+
+    Notes
+    -----
+    **(Korean)** Library 클래스는 라이브러리 관리 기능을 구현한다.
+
+    """
+
+    pass
+
+class TemplateLibrary(LibraryWrapper[Template]):
+    """Class implementing template libraries with templates as child objects."""
 
     # TODO: implement this.
     pass
 
 
-class GridLibrary(Library):
-    """This class implements layout libraries that contain grid objectss as their child objects."""
+class GridLibrary(LibraryWrapper[Grid]):
+    """Class implementing grid libraries with grids as child objects."""
 
     # TODO: implement this.
     pass
@@ -565,11 +578,10 @@ class GridLibrary(Library):
 
 class Design(BaseDatabase):
     """
-    Design class implements the design management function.
+    Class for design management function implementation.
 
     Example
     -------
-
     A physical (non-abstract) grid example:
 
     >>> import laygo2
@@ -749,7 +761,7 @@ class Design(BaseDatabase):
 
     @property
     def bbox(self):
-        """get the design bbox which is union of self.instances.bbox."""
+        """Get design bounding box by taking union of instances' bounding boxes."""
         libname = self.libname
         cellname = self.cellname
         # Compute boundaries
@@ -759,19 +771,21 @@ class Design(BaseDatabase):
                 xy[0] = i.bbox[0]  # bl
                 xy[1] = i.bbox[1]  # tr
             else:
-                xy[0][0] = min(xy[0][0], i.bbox[0, 0])
-                xy[0][1] = min(xy[0][1], i.bbox[0, 1])
-                xy[1][0] = max(xy[1][0], i.bbox[1, 0])
-                xy[1][1] = max(xy[1][1], i.bbox[1, 1])
+                xy = np.minimum(xy, i.bbox)
+                # xy[0][0] = min(xy[0][0], i.bbox[0, 0])
+                # xy[0][1] = min(xy[0][1], i.bbox[0, 1])
+                # xy[1][0] = max(xy[1][0], i.bbox[1, 0])
+                # xy[1][1] = max(xy[1][1], i.bbox[1, 1])
         for n, i in self.virtual_instances.items():
             if xy[0] is None:
                 xy[0] = i.bbox[0]
                 xy[1] = i.bbox[1]
             else:
-                xy[0][0] = min(xy[0][0], i.bbox[0, 0])
-                xy[0][1] = min(xy[0][1], i.bbox[0, 1])
-                xy[1][0] = max(xy[1][0], i.bbox[1, 0])
-                xy[1][1] = max(xy[1][1], i.bbox[1, 1])
+                xy = np.minimum(xy, i.bbox)
+                # xy[0][0] = min(xy[0][0], i.bbox[0, 0])
+                # xy[0][1] = min(xy[0][1], i.bbox[0, 1])
+                # xy[1][0] = max(xy[1][0], i.bbox[1, 0])
+                # xy[1][1] = max(xy[1][1], i.bbox[1, 1])
         xy = np.array(xy)
         return xy
 
@@ -782,7 +796,7 @@ class Design(BaseDatabase):
         self._libname = val
 
     libname = property(get_libname, set_libname)
-    """str: Library name of Design object.
+    """str: Design object's library name.
 
     Example
     -------
@@ -803,7 +817,7 @@ class Design(BaseDatabase):
         self.name = val
 
     cellname = property(get_cellname, set_cellname)
-    """str: Cell name of Design object.
+    """str: Design object's cell name.
 
     Example
     -------
@@ -911,7 +925,7 @@ class Design(BaseDatabase):
     """
 
     def __iter__(self):
-        """Iterator function. Directly mapped to its elements.
+        """Element-mapped direct iterator function.
 
         Example
         -------
@@ -939,7 +953,7 @@ class Design(BaseDatabase):
 
     def __init__(self, name, params=None, elements=None, libname=None):
         """
-        Constructor function of Design class.
+        Design class constructor function.
 
         Parameters
         ----------
@@ -990,7 +1004,7 @@ class Design(BaseDatabase):
         BaseDatabase.__init__(self, name=name, params=params, elements=elements)
 
     def append(self, item):
-        """(Simply) add a physical object to the design.
+        """Add physical object to Design without taking any further actions.
 
         Parameters
         ----------
@@ -1070,7 +1084,7 @@ class Design(BaseDatabase):
             return item_name, item
 
     def summarize(self):
-        """Return the summary of the object information."""
+        """Get object information summary."""
         return (
             BaseDatabase.summarize(self)
             + " \n"
@@ -1100,27 +1114,24 @@ class Design(BaseDatabase):
     # Object creation and manipulation functions.
     def place(self, inst, grid, mn=[0, 0], anchor_xy=None):
         """
-        Place the instance on the abstract coordinate **mn**, on the abstract grid.
+        Place instance at abstract coordinate mn on abstract grid.
 
         Parameters
         ----------
         inst : laygo2.object.physical.Instance or laygo2.object.physical.VirtualInstance or list
-            The instance to be placed. When inst is a list, the elements
-            in the list are placed in order.
+            Instance(s) to be placed (when list, placed in order).
         grid : laygo2.object.grid.PlacementGrid
-            The placement grid where the instance is placed on.
+            Placement grid for instance placement.
         mn : numpy.ndarray or list
-            The abstract coordinate value [m, n] to place the instance.
+            Abstract coordinate value [m, n] for instance placement.
         anchor_xy : list
-            Two physical coordinates to be overlapped by the placement.
-            The first coordinate is for the absolute physical grid, and the
-            second coordinate is for the relative position of the instance
-            to be placed.
+            A list that contains two overlap coordinates for placement 
+            (1st for absolute physical grid, 2nd for relative instance position).
 
         Returns
         -------
         laygo2.object.physical.Instance or laygo2.object.physical.VirtualInstance or list(laygo2.object.physical.Instance):
-            The placed instance or a list containing the placed instances.
+            Placed instance(s) (list if multiple).
 
         Example
         -------
@@ -1257,14 +1268,14 @@ class Design(BaseDatabase):
 
     def route(self, grid, mn, direction=None, via_tag=None):
         """
-        Create wire object(s) for routing, on the abstract coordinate **mn**.
+        Create wire object(s) for routing at abstract coordinate **mn**.
 
         Parameters
         ----------
         grid : laygo2.object.grid.RoutingGrid
-            The placement grid where the wire is placed on.
+            Placement grid for wire placement.
         mn : list(numpy.ndarray)
-            The list containing two or more mn coordinates to be connected.
+            List containing two or more **mn** coordinates to be connected.
         direction : str, optional.
             None or “vertical” or "horizontal". The direction of the routing
             object.
